@@ -1,6 +1,7 @@
 import asyncio
 import inspect
 import logging
+import sys
 from datetime import datetime, timedelta
 from functools import wraps
 from os import getenv
@@ -158,6 +159,9 @@ class SpellBot(discord.Client):
                     discord_user = self.get_user(user.xid)
                     if discord_user:
                         await discord_user.send(s("expired", window=game.server.expire))
+                    user.queued_at = None
+                    user.game = None
+                game.tags = []
                 session.delete(game)
             session.commit()
         except exc.SQLAlchemyError as e:
@@ -207,7 +211,10 @@ class SpellBot(discord.Client):
         """Deletes games older than the given window of minutes."""
         session = self.data.Session()
         try:
-            session.query(Game).filter(Game.url != None).delete()
+            games = session.query(Game).filter(Game.url != None).all()
+            for game in games:
+                game.tags = []
+                session.delete(game)
             session.commit()
         except exc.SQLAlchemyError as e:
             logging.error("error: cleanup_started_games:", e)
@@ -389,6 +396,7 @@ class SpellBot(discord.Client):
             "\n💜 You can help keep SpellBot running by supporting me on Ko-fi! "
             "<https://ko-fi.com/Y8Y51VTHZ>"
         )
+        await channel.send(s("dm_sent"))
         for page in paginate(usage):
             await author.send(page)
 
@@ -453,7 +461,7 @@ class SpellBot(discord.Client):
         params = [param.lower() for param in params]
         user = self.ensure_user_exists(author)
         if user.waiting:
-            return await author.send(s("play_already"))
+            return await channel.send(s("play_already"))
 
         size = 4
         power = None
@@ -464,19 +472,19 @@ class SpellBot(discord.Client):
                 power = to_int(param.replace("power:", ""))
 
         if not size or not (1 < size < 5):
-            return await author.send(s("play_size_bad"))
+            return await channel.send(s("play_size_bad"))
 
         if power and not (1 <= power <= 10):
-            return await author.send(s("play_power_bad"))
+            return await channel.send(s("play_power_bad"))
 
         if len(mentions) >= size:
-            return await author.send(s("play_too_many_mentions"))
+            return await channel.send(s("play_too_many_mentions"))
 
         mentioned_users = []
         for mentioned in mentions:
             mentioned_user = self.ensure_user_exists(mentioned)
             if mentioned_user.waiting:
-                return await author.send(s("play_mention_already", user=mentioned))
+                return await channel.send(s("play_mention_already", user=mentioned))
             mentioned_users.append(mentioned_user)
 
         tags = []
@@ -493,7 +501,7 @@ class SpellBot(discord.Client):
         if not tag_names:
             tag_names = ["default"]
         if len(tag_names) > 5:
-            return await author.send(s("play_too_many_tags"))
+            return await channel.send(s("play_too_many_tags"))
         for tag_name in tag_names:
             tag = self.session.query(Tag).filter_by(name=tag_name).first()
             if not tag:
@@ -521,6 +529,7 @@ class SpellBot(discord.Client):
                 else:
                     found_discord_users.append(discord_user)
 
+        await channel.send(s("dm_sent"))
         if len(found_discord_users) == size:  # all players matched, game is ready
             user.game.url = self.create_game()
             game_created_at = datetime.utcnow()
@@ -547,10 +556,10 @@ class SpellBot(discord.Client):
         """
         user = self.ensure_user_exists(author)
         if not user.waiting:
-            return await author.send(s("leave_already"))
+            return await channel.send(s("leave_already"))
 
         user.dequeue()
-        await author.send(s("leave"))
+        await channel.send(s("leave"))
 
     @command(allow_dm=False)
     async def status(self, prefix, channel, author, mentions, params):
@@ -578,6 +587,7 @@ class SpellBot(discord.Client):
 
         The following subcommands are supported:
 
+        * `config`: Just show the current configuration for this server.
         * `channel <list>`: Set SpellBot to only respond in the given list of channels.
         * `prefix <string>`: Set SpellBot prefix for commands in text channels.
         * `scope <server|channel>`: Set matchmaking scope to server-wide or channel-only.
@@ -587,9 +597,9 @@ class SpellBot(discord.Client):
         & <subcommand> [subcommand parameters]
         """
         if not is_admin(channel, author):
-            return await author.send(s("not_admin"))
+            return await channel.send(s("not_admin"))
         if not params:
-            return await author.send(s("spellbot_missing_subcommand"))
+            return await channel.send(s("spellbot_missing_subcommand"))
         self.ensure_server_exists(channel.guild.id)
         command = params[0]
         if command == "channels":
@@ -600,24 +610,26 @@ class SpellBot(discord.Client):
             await self.spellbot_scope(prefix, channel, author, mentions, params[1:])
         elif command == "expire":
             await self.spellbot_expire(prefix, channel, author, mentions, params[1:])
+        elif command == "config":
+            await self.spellbot_config(prefix, channel, author, mentions, params[1:])
         else:
-            await author.send(s("spellbot_unknown_subcommand", command=command))
+            await channel.send(s("spellbot_unknown_subcommand", command=command))
 
     async def spellbot_channels(self, prefix, channel, author, mentions, params):
         if not params:
-            return await author.send(s("spellbot_channels_none"))
+            return await channel.send(s("spellbot_channels_none"))
         self.session.query(AuthorizedChannel).filter_by(
             guild_xid=channel.guild.id
         ).delete()
         for param in params:
             self.session.add(AuthorizedChannel(guild_xid=channel.guild.id, name=param))
-        return await author.send(
+        return await channel.send(
             s("spellbot_channels", channels=", ".join([f"#{param}" for param in params]))
         )
 
     async def spellbot_prefix(self, prefix, channel, author, mentions, params):
         if not params:
-            return await author.send(s("spellbot_prefix_none"))
+            return await channel.send(s("spellbot_prefix_none"))
         prefix_str = params[0][0:10]
         server = (
             self.session.query(Server)
@@ -629,10 +641,10 @@ class SpellBot(discord.Client):
 
     async def spellbot_scope(self, prefix, channel, author, mentions, params):
         if not params:
-            return await author.send(s("spellbot_scope_none"))
+            return await channel.send(s("spellbot_scope_none"))
         scope_str = params[0].lower()
         if scope_str not in ("server", "channel"):
-            return await author.send(s("spellbot_scope_bad"))
+            return await channel.send(s("spellbot_scope_bad"))
         server = (
             self.session.query(Server)
             .filter(Server.guild_xid == channel.guild.id)
@@ -643,17 +655,43 @@ class SpellBot(discord.Client):
 
     async def spellbot_expire(self, prefix, channel, author, mentions, params):
         if not params:
-            return await author.send(s("spellbot_expire_none"))
+            return await channel.send(s("spellbot_expire_none"))
         expire = to_int(params[0])
-        if not expire or not (10 < expire < 60):
-            return await author.send(s("spellbot_expire_bad"))
+        if not expire or not (0 < expire <= 60):
+            return await channel.send(s("spellbot_expire_bad"))
         server = (
             self.session.query(Server)
             .filter(Server.guild_xid == channel.guild.id)
             .one_or_none()
         )
         server.expire = expire
-        return await author.send(s("spellbot_expire", expire=expire))
+        return await channel.send(s("spellbot_expire", expire=expire))
+
+    async def spellbot_config(self, prefix, channel, author, mentions, params):
+        server = (
+            self.session.query(Server)
+            .filter(Server.guild_xid == channel.guild.id)
+            .one_or_none()
+        )
+        embed = discord.Embed(title="SpellBot Server Config")
+        thumb = (
+            "https://raw.githubusercontent.com/lexicalunit/spellbot/master/spellbot.png"
+        )
+        embed.set_thumbnail(url=thumb)
+        embed.add_field(name="Command prefix", value=server.prefix)
+        scope = "server-wide" if server.scope == "server" else "channel-specific"
+        embed.add_field(name="Queue scope", value=scope)
+        expires_str = f"{server.expire} minutes"
+        embed.add_field(name="Inactivity expiration time", value=expires_str)
+        channels = server.authorized_channels
+        if channels:
+            channels_str = ", ".join(f"#{channel.name}" for channel in channels)
+        else:
+            channels_str = "all"
+        embed.add_field(name="Authorized channels", value=channels_str)
+        embed.color = discord.Color(0x5A3EFD)
+        embed.set_footer(text=f"Config for Guild ID: {server.guild_xid}")
+        await channel.send(embed=embed, file=None)
 
 
 def get_db_env(fallback):  # pragma: no cover
@@ -726,9 +764,19 @@ def main(
     # before we try to create we can run any of the migrations.
     ensure_application_directories_exist()
 
+    token = getenv("SPELLBOT_TOKEN", None)
+    if not token:
+        print("error: SPELLBOT_TOKEN environment variable not set", file=sys.stderr)
+        sys.exit(1)
+
+    auth = getenv("SPELLTABLE_AUTH", None)
+    if not auth:
+        print("error: SPELLTABLE_AUTH environment variable not set", file=sys.stderr)
+        sys.exit(1)
+
     client = SpellBot(
-        token=getenv("SPELLBOT_TOKEN", None),
-        auth=getenv("SPELLTABLE_AUTH", None),
+        token=token,
+        auth=auth,
         db_url=database_url,
         log_level="DEBUG" if verbose else log_level,
         mock_games=mock_games,
