@@ -8,6 +8,7 @@ from sqlalchemy import (
     BigInteger,
     Column,
     DateTime,
+    Float,
     ForeignKey,
     Integer,
     String,
@@ -148,9 +149,20 @@ class User(Base):
         now = datetime.utcnow()
         expires_at = now + timedelta(minutes=server.expire)
         if existing_game:
+            already_seated = len(existing_game.users)
             self.game = existing_game
             self.game.updated_at = now
             self.game.expires_at = expires_at
+            if power:
+                newly_seated = 1 + len(include)
+                now_seated = already_seated + newly_seated
+                print(
+                    f"power: (({self.game.power} * {already_seated}) +"
+                    f" ({power} * {newly_seated})) / {now_seated} "
+                )
+                self.game.power = (
+                    (self.game.power * already_seated) + (power * newly_seated)
+                ) / now_seated
         else:
             self.game = Game(
                 channel_xid=channel_xid if server.scope == "channel" else None,
@@ -187,7 +199,7 @@ class Game(Base):
         BigInteger, ForeignKey("servers.guild_xid", ondelete="CASCADE"), nullable=False
     )
     channel_xid = Column(BigInteger)
-    power = Column(Integer)
+    power = Column(Float)
     url = Column(String(255))
     users = relationship("User", back_populates="game")
     tags = relationship("Tag", secondary=games_tags, back_populates="games")
@@ -209,8 +221,8 @@ class Game(Base):
             rvalue += f"{self.url}\n"
         else:
             rvalue += (
-                "**You have been entered in a play queue "
-                f"for a {self.size} player game.**"
+                "**You have been entered in a play queue"
+                f" for a {self.size} player game.**"
             )
             average = WaitTime.average(
                 session,
@@ -224,6 +236,9 @@ class Game(Base):
                 rvalue += f" _The average wait time is {delta}._\n"
             else:
                 rvalue += "\n"
+        rvalue += (
+            "\n🚨 When your game is ready I will send you another Direct Message! 🚨\n\n"
+        )
         players = ", ".join(sorted([f"<@{user.xid}>" for user in self.users]))
         rvalue += f"Players: {players}\n"
         if self.channel_xid:
@@ -232,7 +247,7 @@ class Game(Base):
             tag_names = ", ".join(sorted([tag.name for tag in self.tags]))
             rvalue += f"Tags: {tag_names}\n"
         if self.power:
-            rvalue += f"Power Level: {self.power}\n"
+            rvalue += f"Average Power Level: {self.power:.1f}\n"
         return rvalue.strip()
 
 
